PolylineRF class

Implemented types

Constructors

PolylineRF({required List<CoordinateRF> Points, required Color color, required double BorderStrokeWidth, required Color BorderColor, required double StrokeWidth, bool isSolidPattern = true})

Properties

BorderColor → Color
final
BorderStrokeWidth → double
final
color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
isSolidPattern → bool
final
Points → List<CoordinateRF>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
StrokeWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OnTap() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited