MarkerRF class

Constructors

MarkerRF({required String Id, CoordinateRF? Positions, required String Image, double Width = 50, double Height = 50, String Type = "pin", Alignment alignment = Alignment.center, double? Bearing, int? Duration, double? heading, bool? Draggable = true, bool Visible = false, TickerProvider onTap()?, IAnimateRF? Animate, EdgeInsets? padding})

Properties

alignment ↔ Alignment
getter/setter pair
Animate ↔ IAnimateRF?
getter/setter pair
Bearing ↔ double?
getter/setter pair
Draggable ↔ bool?
getter/setter pair
Duration ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heading ↔ double?
getter/setter pair
Height ↔ double
getter/setter pair
Id ↔ String
getter/setter pair
Image ↔ String
getter/setter pair
onTap ↔ TickerProvider Function()?
getter/setter pair
padding ↔ EdgeInsets?
getter/setter pair
Positions ↔ CoordinateRF?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Type ↔ String
getter/setter pair
Visible ↔ bool
getter/setter pair
Width ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
OnDrag() → dynamic
OnDragEnd() → dynamic
OnDragStart() → dynamic
OnTap() → dynamic
OSMMarkerRF() → dynamic
SetPosition() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited