ButtonSearchRF class

Inheritance

Constructors

ButtonSearchRF({Key? key, required List<ChipRF> Chips, required MapControllerRF controller, int? selectedIndex, double? elevation, Color? shadowColor, bool autofocus = false, BoxConstraints? avatarBoxConstraints, BoxConstraints? deleteIconBoxConstraints, Clip clipBehavior = Clip.none, String? deleteButtonTooltipMessage, Widget? deleteIcon, FocusNode? focusNode, EdgeInsetsGeometry? labelPadding, TextStyle? labelStyle, MaterialTapTargetSize? materialTapTargetSize, VoidCallback? onDeleted, EdgeInsetsGeometry? padding, BorderSide? side, OutlinedBorder? shape, Color? surfaceTintColor, VisualDensity? visualDensity, Color? deleteIconColor, IconThemeData? iconTheme})

Properties

autofocus → bool
final
avatarBoxConstraints → BoxConstraints?
final
Chips → List<ChipRF>
final
clipBehavior → Clip
final
controller → MapControllerRF
final
deleteButtonTooltipMessage → String?
final
deleteIcon → Widget?
final
deleteIconBoxConstraints → BoxConstraints?
final
deleteIconColor → Color?
final
elevation → double?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
iconTheme → IconThemeData?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelPadding → EdgeInsetsGeometry?
final
labelStyle → TextStyle?
final
materialTapTargetSize → MaterialTapTargetSize?
final
onDeleted → VoidCallback?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex ↔ int?
getter/setter pair
shadowColor → Color?
final
shape → OutlinedBorder?
final
side → BorderSide?
final
surfaceTintColor → Color?
final
visualDensity → VisualDensity?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ButtonSearchRF>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited