ChipRF class

Constructors

ChipRF({required Widget label, Widget? avatar, Future<ShapesInfoRF> onTap()?, ChipTypeRF? chipTypeRF, Color backgroundColor = Colors.white, Color? selectedColor})

Properties

avatar → Widget?
final
backgroundColor ↔ Color
getter/setter pair
chipTypeRF ↔ ChipTypeRF?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ Widget
getter/setter pair
onTap ↔ Future<ShapesInfoRF> Function()?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor ↔ Color?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited