ShapesInfoRF class

Constructors

ShapesInfoRF({List<MarkerRF>? markers, PolylineRF? polyline, List<IShapeRF>? Fences})

Properties

Fences ↔ List<IShapeRF>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
markers ↔ List<MarkerRF>?
getter/setter pair
polyline ↔ PolylineRF?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited