zoomLevel property
Zoom level applied when navigating to the current location. Falls back to the map's InitialZoom when null.
Implementation
double? zoomLevel;
Zoom level applied when navigating to the current location. Falls back to the map's InitialZoom when null.
double? zoomLevel;